#!/bin/bash
#------------------------------------------------------------------------
# generate_tvwfile.sh  writes time-varying weir file to scenario directory
#------------------------------------------------------------------------
THIS=$(basename -- $0)
#
EXIT_SUCCESS=0
EXIT_ERROR=1
declare -A properties
SCENARIODIR=$PWD 
## When BUILD_FORECAST_SCENARIO runs, SCENARIODIR is still the nowcast folder
## The result is that the barrier hadn't actually shut during the forecast
## This next bit of code gets us around that by replacing "nowcast" with "forecast"
#SCENARIODIR=${SCENARIODIR//nowcast/forecast}

RUNPROPERTIES=$SCENARIODIR/run.properties
if [[ $# -eq 1 ]]; then
   RUNPROPERTIES=$1
   SCENARIODIR=`dirname $RUNPROPERTIES`
   MANUAL=1
fi
# this script can be called with just one command line option: the
# full path to the run.properties file
echo "Loading properties."
# get loadProperties function
SCRIPTDIR=`sed -n 's/[ ^]*$//;s/path.scriptdir\s*:\s*//p' $RUNPROPERTIES`
source $SCRIPTDIR/properties.sh
source $SCRIPTDIR/monitoring/logging.sh
# load run.properties file into associative array
loadProperties $RUNPROPERTIES
echo "Finished loading properties."
COLDSTARTDATE=${properties["adcirc.time.coldstartdate"]}
WEIRCLOSEDATE=${properties["adcirc.tvw.weirclosedate"]} 
INPUTDIR=${properties["path.inputdir"]}
STORMDIR=${properties["path.stormdir"]}
SYSLOG=${properties['monitoring.logging.file.syslog']}
#ENSTORM=${properties['enstorm']}
#if [ $ENSTORM == 'nowcast']
#   echo "nowcast"
#fi	
INFILE=$INPUTDIR/time_varying_weir.in_template
#OUTFILE=$STORMDIR/time-bonnet.in
OUTFILE=$SCENARIODIR/time_varying_weir.in

MSG="$THIS: running write_tvwfile.sh with args: $INFILE $OUTFILE $COLDSTARTDATE $WEIRCLOSEDATE"
if [ "$MANUAL" == 1 ]; then
   echo "$MSG"
else
   allMessage "$MSG" >> "$SYSLOG"
fi
$SCRIPTDIR/write_tvwfile.sh $INFILE $OUTFILE $COLDSTARTDATE $WEIRCLOSEDATE
