#!/bin/bash
# write start and end times of weir closure into time varying weir file using template file
# input args:
# template file (time_varying_weir.in_template):
INFILE=$1
# output file (usually time_varying_weir.in):
OUTFILE=$2
# adcirc coldstart date from config file (YYYYMMDDHH, where HH=0-24)
COLDSTARTDATE=$3
# date of start of weir closure (YYYYMMDDHH)
WEIRCLOSEDATE=$4

weir_close_duration_hrs=1

echo write_tvwfile.sh: infile=$INFILE
echo write_tvwfile.sh: outfile=$OUTFILE

CSY=`echo $COLDSTARTDATE | cut -c 1-4`
CSM=`echo $COLDSTARTDATE | cut -c 5,6`
CSD=`echo $COLDSTARTDATE | cut -c 7,8`
CSH=`echo $COLDSTARTDATE | cut -c 9,10`

WCY=`echo $WEIRCLOSEDATE | cut -c 1-4`
WCM=`echo $WEIRCLOSEDATE | cut -c 5,6`
WCD=`echo $WEIRCLOSEDATE | cut -c 7,8`
WCH=`echo $WEIRCLOSEDATE | cut -c 9,10`

echo Cold start at: $CSY/$CSM/$CSD/$CSH
echo Start Weir close at: $WCY/$WCM/$WCD/$WCH

# get time in seconds from reference unix time
tcs=`date -u -d "$CSY-$CSM-$CSD $CSH:00" +%s`
twc=`date -u -d "$WCY-$WCM-$WCD $WCH:00" +%s`
echo coldstart time = $tcs
echo weir close time = $twc

# compute start time of weir closure
dtsec=`echo "$twc-$tcs" | bc`
twc_sday=`echo "$dtsec/86400" | bc`
twc_shour=`echo "($dtsec - ($twc_sday*86400) )/3600" | bc`
twc_smin=`echo "($dtsec - ($twc_sday*86400) - ($twc_shour*3600) )/60" | bc`
echo start weir closure at $twc_sday days $twc_shour hours $twc_smin minutes

# compute end time of weir closure
twc=`echo "$twc + 3600*$weir_close_duration_hrs" | bc`
dtsec=`echo "$twc-$tcs" | bc`
twc_eday=`echo "$dtsec/86400" | bc`
twc_ehour=`echo "($dtsec - ($twc_eday*86400) )/3600" | bc`
twc_emin=`echo "($dtsec - ($twc_eday*86400) - ($twc_ehour*3600) )/60" | bc`
echo end weir closure at $twc_eday days $twc_ehour hours $twc_emin minutes

# write time values into file
sed "s;%StartDay%;$twc_sday;" $INFILE > tmp1.txt
sed "s;%StartHour%;$twc_shour;" tmp1.txt > tmp2.txt
sed "s;%StartMin%;$twc_smin;" tmp2.txt > tmp3.txt
sed "s;%EndDay%;$twc_eday;" tmp3.txt > tmp4.txt
sed "s;%EndHour%;$twc_ehour;" tmp4.txt > tmp5.txt
sed "s;%EndMin%;$twc_emin;" tmp5.txt > $OUTFILE
rm -f tmp1.txt tmp2.txt tmp3.txt tmp4.txt tmp5.txt
